// src/index.ts
import { createCombinePlugin } from "unplugin-combine";
import VueBetterDefine from "@vue-macros/better-define";
import VueDefineModel from "@vue-macros/define-model";
import VueDefineOptions from "unplugin-vue-define-options";
import VueDefineProps from "@vue-macros/define-props";
import VueDefineRender from "@vue-macros/define-render";
import VueDefineSlots from "@vue-macros/define-slots";
import VueExportProps from "@vue-macros/export-props";
import VueHoistStatic from "@vue-macros/hoist-static";
import VueNamedTemplate from "@vue-macros/named-template";
import VueReactivityTransformVue2 from "@vue-macros/reactivity-transform-vue2";
import VueSetupBlock from "@vue-macros/setup-block";
import VueSetupComponent from "@vue-macros/setup-component";
import VueSetupSFC from "@vue-macros/setup-sfc";
import VueShortEmits from "@vue-macros/short-emits";
import { detectVueVersion } from "@vue-macros/common";
function resolveOptions({
  root,
  version,
  plugins,
  isProduction,
  betterDefine,
  defineModel,
  defineOptions,
  defineProps,
  defineRender,
  defineSlots,
  exportProps,
  hoistStatic,
  namedTemplate,
  reactivityTransformVue2,
  setupBlock,
  setupComponent,
  setupSFC,
  shortEmits
}) {
  function resolveSubOptions(options, commonOptions = {}, defaultEnabled = true) {
    options = options ?? defaultEnabled;
    if (!options)
      return false;
    else if (options === true)
      return { ...commonOptions };
    else
      return { ...options, ...commonOptions };
  }
  root = root || process.cwd();
  version = version || detectVueVersion();
  isProduction = isProduction ?? process.env.NODE_ENV === "production";
  return {
    plugins: plugins || {},
    betterDefine: resolveSubOptions(betterDefine, {
      isProduction
    }),
    defineModel: resolveSubOptions(defineModel, { version }),
    defineOptions: resolveSubOptions(defineOptions, {
      version
    }),
    defineProps: resolveSubOptions(defineProps, { version }),
    defineRender: resolveSubOptions(defineRender),
    defineSlots: resolveSubOptions(defineSlots, { version }),
    exportProps: resolveSubOptions(exportProps, { version }),
    hoistStatic: resolveSubOptions(hoistStatic),
    namedTemplate: resolveSubOptions(namedTemplate),
    reactivityTransformVue2: resolveSubOptions(
      reactivityTransformVue2,
      void 0,
      version === 2
    ),
    setupBlock: resolveSubOptions(setupBlock, void 0, false),
    setupComponent: resolveSubOptions(setupComponent, {
      root
    }),
    setupSFC: resolveSubOptions(setupSFC),
    shortEmits: resolveSubOptions(shortEmits)
  };
}
function resolvePlugin(unplugin, framework, options) {
  if (!options)
    return;
  return unplugin[framework](options);
}
var name = "unplugin-vue-macros";
var src_default = createCombinePlugin((userOptions = {}, meta) => {
  const options = resolveOptions(userOptions);
  const framework = meta.framework;
  const setupComponentPlugins = resolvePlugin(
    VueSetupComponent,
    framework,
    options.setupComponent
  );
  const namedTemplatePlugins = resolvePlugin(
    VueNamedTemplate,
    framework,
    options.namedTemplate
  );
  const plugins = [
    resolvePlugin(VueSetupSFC, framework, options.setupSFC),
    setupComponentPlugins == null ? void 0 : setupComponentPlugins[0],
    resolvePlugin(VueSetupBlock, framework, options.setupBlock),
    resolvePlugin(VueHoistStatic, framework, options.hoistStatic),
    namedTemplatePlugins == null ? void 0 : namedTemplatePlugins[0],
    resolvePlugin(VueDefineProps, framework, options.defineProps),
    resolvePlugin(VueExportProps, framework, options.exportProps),
    resolvePlugin(VueShortEmits, framework, options.shortEmits),
    resolvePlugin(VueDefineModel, framework, options.defineModel),
    resolvePlugin(VueDefineSlots, framework, options.defineSlots),
    resolvePlugin(
      VueReactivityTransformVue2,
      framework,
      options.reactivityTransformVue2
    ),
    resolvePlugin(VueBetterDefine, framework, options.betterDefine),
    resolvePlugin(VueDefineOptions, framework, options.defineOptions),
    options.plugins.vue,
    options.plugins.vueJsx,
    resolvePlugin(VueDefineRender, framework, options.defineRender),
    setupComponentPlugins == null ? void 0 : setupComponentPlugins[1],
    namedTemplatePlugins == null ? void 0 : namedTemplatePlugins[1]
  ].filter(Boolean);
  return {
    name,
    plugins
  };
});

export {
  src_default
};
